/***************************************************************************
                          fileio.cpp  -  description
                             -------------------
    begin                : Thu Oct 11 2001
    copyright            : (C) 2001 by Martin Bickel
    email                : bickel@asc-hq.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


 const char* filereadmode = "r";
 const char* filewritemode = "w";
 const char* filereadmodetext = "r";
 const char* filewritemodetext = "w";
 const char pathdelimitter = '/';
 const char* pathdelimitterstring = "/";
 const char  foreignPathDelimitter = '\\';
 const char* foreignPathDelimitterString = "\\";

 const int maxfilenamelength = 255;
 const char* asc_configurationfile = "asc2rc";
 const bool has_drive_letters = false;
